@@ -26,9 +26,11 @@ from faker.providers.date_time.de_DE import Provider as DeDeProvider
 from faker.providers.date_time.el_GR import Provider as ElGrProvider
 from faker.providers.date_time.es_ES import Provider as EsEsProvider
 from faker.providers.date_time.fr_FR import Provider as FrFrProvider
+from faker.providers.date_time.gu_IN import Provider as GuINProvider
 from faker.providers.date_time.hy_AM import Provider as HyAmProvider
 from faker.providers.date_time.it_IT import Provider as ItItProvider
 from faker.providers.date_time.ja_JP import Provider as JaJpProvider
+from faker.providers.date_time.ka_GE import Provider as KaGeProvider
 from faker.providers.date_time.nl_NL import Provider as NlProvider
 from faker.providers.date_time.no_NO import Provider as NoNoProvider
 from faker.providers.date_time.pl_PL import Provider as PlProvider
@@ -40,6 +42,7 @@ from faker.providers.date_time.sk_SK import Provider as SkSkProvider
 from faker.providers.date_time.sl_SI import Provider as SlSiProvider
 from faker.providers.date_time.ta_IN import Provider as TaInProvider
 from faker.providers.date_time.tr_TR import Provider as TrTrProvider
+from faker.providers.date_time.vi_VN import Provider as ViVNProvider
 from faker.providers.date_time.zh_CN import Provider as ZhCnProvider
 from faker.providers.date_time.zh_TW import Provider as ZhTwProvider
 
@@ -114,6 +117,14 @@ class TestDateTime(unittest.TestCase):
         past_date = self.fake.past_date()
         assert past_date < date.today()
 
+    def test_past_date_string(self):
+        date_format = "%Y-%m-%d"
+        date_string = self.fake.past_date(pattern=date_format)
+        assert isinstance(date_string, str)
+        past_date = datetime.strptime(date_string, date_format).date()
+        assert isinstance(past_date, date)
+        assert past_date < date.today()
+
     def test_future_datetime(self):
         future_datetime, now = self.fake.future_datetime(), datetime.now()
         assert future_datetime > now
@@ -122,6 +133,14 @@ class TestDateTime(unittest.TestCase):
         future_date = self.fake.future_date()
         assert future_date > date.today()
 
+    def test_future_date_string(self):
+        date_format = "%Y-%m-%d"
+        date_string = self.fake.future_date(pattern=date_format)
+        assert isinstance(date_string, str)
+        future_date = datetime.strptime(date_string, date_format).date()
+        assert isinstance(future_date, date)
+        assert future_date > date.today()
+
     def test_parse_date_time(self):
         timestamp = DatetimeProvider._parse_date_time("+30d")
         now = DatetimeProvider._parse_date_time("now")
@@ -193,11 +212,17 @@ class TestDateTime(unittest.TestCase):
         assert self.fake.iso8601(tzinfo=utc, sep=" ")[10] == " "
         assert self.fake.iso8601(tzinfo=utc, sep="_")[10] == "_"
 
-    @pytest.mark.skipif(not sys.platform.startswith("win"), reason="windows does not support sub second precision")
+    @pytest.mark.skipif(
+        not sys.platform.startswith("win"),
+        reason="windows does not support sub second precision",
+    )
     def test_iso8601_fractional_seconds_win(self):
         assert len(self.fake.iso8601()) == 19
 
-    @pytest.mark.skipif(sys.platform.startswith("win"), reason="non windows does support sub second precision")
+    @pytest.mark.skipif(
+        sys.platform.startswith("win"),
+        reason="non windows does support sub second precision",
+    )
     def test_iso8601_fractional_seconds_non_win(self):
         assert len(self.fake.iso8601()) == 26
 
@@ -234,6 +259,10 @@ class TestDateTime(unittest.TestCase):
         assert datetime_start <= random_date
         assert datetime_end >= random_date
 
+    def test_date_time_between_dates_with_no_date_overlap(self):
+        with pytest.raises(ValueError):
+            self.fake.date_time_between_dates("-1y", "-2y")
+
     def test_date_time_between_dates_with_tzinfo(self):
         timestamp_start = random.randint(0, 2000000000)
         timestamp_end = timestamp_start + 1
@@ -261,6 +290,15 @@ class TestDateTime(unittest.TestCase):
         assert date_start <= random_date
         assert date_end >= random_date
 
+    def test_date_string_between_dates(self):
+        date_end = date.today()
+        date_start = date_end - timedelta(days=10)
+        date_format = "%Y-%m-%d"
+
+        date_string = self.fake.date_between_dates(date_start, date_end, pattern=date_format)
+        assert isinstance(date_string, str)
+        assert isinstance(datetime.strptime(date_string, date_format), datetime)
+
     def test_date_time_between_long_past_dates(self):
         random_date = self.fake.date_between("-100y", "-50y")
         assert random_date
@@ -400,6 +438,18 @@ class TestDateTime(unittest.TestCase):
         assert self.fake.date_this_month(before_today=False, after_today=True) >= date.today()
         assert self.fake.date_this_month(before_today=False, after_today=False) == date.today()
 
+    @unittest.skipUnless(is64bit(), "requires 64bit")
+    def test_date_string_this_period(self):
+        date_format = "%Y-%m-%d"
+        # test century
+        assert isinstance(self.fake.date_this_century(pattern=date_format), str)
+        # test decade
+        assert isinstance(self.fake.date_this_decade(pattern=date_format), str)
+        # test year
+        assert isinstance(self.fake.date_this_year(pattern=date_format), str)
+        # test month
+        assert isinstance(self.fake.date_this_month(pattern=date_format), str)
+
     def test_date_time_between(self):
         now = datetime.now()
         _30_years_ago = change_year(now, -30)
@@ -437,6 +487,19 @@ class TestDateTime(unittest.TestCase):
         assert isinstance(random_date, date)
         self.assertBetween(random_date, _9_months_ago, _2_months_ago)
 
+    def test_date_string_between(self):
+        today = date.today()
+        _30_years_ago = change_year(today, -30)
+        _20_years_ago = change_year(today, -20)
+        date_format = "%Y-%m-%d"
+
+        date_string = self.fake.date_between(start_date="-30y", end_date="-20y", pattern=date_format)
+
+        assert isinstance(date_string, str)
+        date_ = datetime.strptime(date_string, date_format).date()
+        assert isinstance(date_, date)
+        self.assertBetween(date_, _30_years_ago, _20_years_ago)
+
     def test_parse_timedelta(self):
         from faker.providers.date_time import Provider
 
@@ -545,13 +608,19 @@ class TestDateTime(unittest.TestCase):
             if platform.system() != "Windows":
                 del os.environ["TZ"]
 
-    @pytest.mark.skipif(not sys.platform.startswith("win"), reason="windows does not support sub second precision")
+    @pytest.mark.skipif(
+        not sys.platform.startswith("win"),
+        reason="windows does not support sub second precision",
+    )
     def test_unix_time_win(self):
         unix_time = self.fake.unix_time()
         assert isinstance(unix_time, float)
         assert unix_time % 1 == 0.0
 
-    @pytest.mark.skipif(sys.platform.startswith("win"), reason="non windows does support sub second precision")
+    @pytest.mark.skipif(
+        sys.platform.startswith("win"),
+        reason="non windows does support sub second precision",
+    )
     def test_unix_time_non_win(self):
         unix_time = self.fake.unix_time()
         assert isinstance(unix_time, float)
@@ -660,6 +729,10 @@ class DatesOfBirth(unittest.TestCase):
         dob = self.fake.date_of_birth()
         assert isinstance(dob, date)
 
+    def test_date_of_birth_string(self):
+        dob_str = self.fake.date_of_birth(pattern="%Y-%m-%d")
+        assert isinstance(dob_str, str)
+
     @freezegun.freeze_time("2020-02-29")
     def test_date_of_birth_on_leap_day(self):
         """
@@ -1285,6 +1358,35 @@ class TestFrCa(unittest.TestCase):
         assert day in FrFrProvider.MONTH_NAMES.values()
 
 
+class TestGuIN(unittest.TestCase):
+    """Test `gu_IN` (Gujarati) provider for date_time"""
+
+    def setUp(self):
+        self.fake = Faker("gu_IN")
+        Faker.seed(0)
+
+    def test_day(self):
+        day = self.fake.day_of_week()
+        assert day in GuINProvider.DAY_NAMES.values()
+
+    def test_month(self):
+        month = self.fake.month_name()
+        assert month in GuINProvider.MONTH_NAMES.values()
+
+    def test_day_in_guj(self):
+        day = self.fake.day_of_week_in_guj()
+        assert day in GuINProvider.DAY_NAMES_IN_GUJARATI.values()
+
+    def test_month_in_guj(self):
+        """Test `month_in_guj` and `month_names_in_guj` methods"""
+
+        month = self.fake.month_name_in_guj()
+        assert month in GuINProvider.MONTH_NAMES_IN_GUJARATI.values()
+
+        month = self.fake.month_in_guj()
+        assert month in GuINProvider.MONTH_NAMES_IN_GUJARATI.values()
+
+
 class TestJaJp(unittest.TestCase):
     def setUp(self):
         self.fake = Faker("ja_JP")
@@ -1301,3 +1403,39 @@ class TestJaJp(unittest.TestCase):
     def test_traditional_month(self):
         month = self.fake.traditional_month_name()
         assert month in JaJpProvider.TRADITIONAL_MONTH_NAMES.values()
+
+
+class TestKaGe(unittest.TestCase):
+    """Test Ka_GE date_time provider methods"""
+
+    def setUp(self):
+        self.fake = Faker("Ka_GE")
+        Faker.seed(0)
+
+    def test_day(self):
+        day = self.fake.day_of_week()
+        assert isinstance(day, str)
+        assert day in KaGeProvider.DAY_NAMES.values()
+
+    def test_month(self):
+        month = self.fake.month_name()
+        assert isinstance(month, str)
+        assert month in KaGeProvider.MONTH_NAMES.values()
+
+
+class TestViVn(unittest.TestCase):
+    """Tests date_time in the vi_VN locale"""
+
+    def setUp(self):
+        self.fake = Faker("vi_VN")
+        Faker.seed(0)
+
+    def test_day(self):
+        day = self.fake.day_of_week()
+        assert isinstance(day, str)
+        assert day in ViVNProvider.DAY_NAMES.values()
+
+    def test_month(self):
+        month = self.fake.month_name()
+        assert isinstance(month, str)
+        assert month in ViVNProvider.MONTH_NAMES.values()
